@@ -1,12 +1,14 @@
 from __future__ import absolute_import
 import os
 import six
+import json
 import django
 from .. import views
 from django.db import models
 from .. import models as bmodels
 from django.conf import settings
 from django.test import TestCase
+from django.http import HttpResponse
 from django.core.management import call_command
 from django.core.management.base import CommandError
 
@@ -24,6 +26,29 @@ class MockDetailView(views.BuildableDetailView):
     template_name = 'detailview.html'
 
 
+class JSONResponseMixin(object):
+
+    def render_to_response(self, context, **response_kwargs):
+        return HttpResponse(
+            self.convert_context_to_json(context),
+            content_type='application/json',
+            **response_kwargs
+        )
+
+    def convert_context_to_json(self, context):
+        return json.dumps(context)
+
+
+class MockJSONView(JSONResponseMixin, views.BuildableTemplateView):
+    build_path = 'jsonview.json'
+
+    def get_content(self):
+        return self.get(self.request).content
+
+    def get_context_data(self, **kwargs):
+        return {'hello': 'tests'}
+
+
 class BakeryTest(TestCase):
 
     def setUp(self):
@@ -103,6 +128,17 @@ class BakeryTest(TestCase):
         self.assertTrue(os.path.exists(build_path))
         os.remove(build_path)
 
+    def test_json_view(self):
+        v = MockJSONView()
+        v.build()
+        build_path = os.path.join(settings.BUILD_DIR, 'jsonview.json')
+        self.assertTrue(os.path.exists(build_path))
+        self.assertEqual(
+            json.loads(open(build_path, 'rb').read().decode()),
+            {"hello": "tests"}
+        )
+        os.remove(build_path)
+
     def test_build_cmd(self):
         call_command("build", **{'skip_media': True, 'verbosity': 3})
         call_command("build", **{'skip_static': True, 'verbosity': 3})
@@ -126,7 +162,7 @@ class BakeryTest(TestCase):
         self.assertTrue(os.path.exists(foobar_path))
         self.assertEqual(
             open(foobar_path, 'rb').read().strip(),
-            'Hello tests'
+            six.b('Hello tests')
         )
         robots_path = os.path.join(settings.BUILD_DIR, 'robots.txt')
         self.assertTrue(os.path.exists(robots_path))
